==============================================
Ansible Collection cloudscale.ch Release Notes
==============================================

.. contents:: Topics


v1.1.0
======

Minor Changes
-------------

- floating_ip - added tags support (https://github.com/cloudscale-ch/ansible-collection-cloudscale/pull/16)

New Modules
-----------

- objects_user - Manages objects users on the cloudscale.ch IaaS service
